# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKNarrowBandPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkNarrowBandImageFilterBasePython
else:
    import _itkNarrowBandImageFilterBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKNarrowBandBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterBPython
import itk.itkFiniteDifferenceFunctionPython
class itkNarrowBandImageFilterBaseIF2IF2(itk.itkFiniteDifferenceImageFilterPython.itkFiniteDifferenceImageFilterIF2IF2):
    r"""Proxy of C++ itkNarrowBandImageFilterBaseIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetIsoSurfaceValue(self, _arg):
        r"""
        SetIsoSurfaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_SetIsoSurfaceValue(self, _arg)

    def GetIsoSurfaceValue(self):
        r"""GetIsoSurfaceValue(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_GetIsoSurfaceValue(self)

    def InsertNarrowBandNode(self, *args):
        r"""
        InsertNarrowBandNode(self, node)

        Parameters
        ----------
        node: itkBandNodeI2F const &

        InsertNarrowBandNode(self, index)

        Parameters
        ----------
        index: itkIndex2 const &

        InsertNarrowBandNode(self, index, value, nodestate)

        Parameters
        ----------
        index: itkIndex2 const &
        value: float const &
        nodestate: signed char const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_InsertNarrowBandNode(self, *args)

    def SetNarrowBandTotalRadius(self, val):
        r"""
        SetNarrowBandTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_SetNarrowBandTotalRadius(self, val)

    def GetNarrowBandTotalRadius(self):
        r"""GetNarrowBandTotalRadius(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_GetNarrowBandTotalRadius(self)

    def SetNarrowBandInnerRadius(self, val):
        r"""
        SetNarrowBandInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_SetNarrowBandInnerRadius(self, val)

    def GetNarrowBandInnerRadius(self):
        r"""GetNarrowBandInnerRadius(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_GetNarrowBandInnerRadius(self)

    def CreateNarrowBand(self):
        r"""CreateNarrowBand(self)"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_CreateNarrowBand(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI2F *

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_SetNarrowBand(self, ptr)

    def CopyInputToOutput(self):
        r"""CopyInputToOutput(self)"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_CopyInputToOutput(self)
    __swig_destroy__ = _itkNarrowBandImageFilterBasePython.delete_itkNarrowBandImageFilterBaseIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandImageFilterBaseIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_cast(obj)

# Register itkNarrowBandImageFilterBaseIF2IF2 in _itkNarrowBandImageFilterBasePython:
_itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF2IF2_swigregister(itkNarrowBandImageFilterBaseIF2IF2)
class itkNarrowBandImageFilterBaseIF3IF3(itk.itkFiniteDifferenceImageFilterPython.itkFiniteDifferenceImageFilterIF3IF3):
    r"""Proxy of C++ itkNarrowBandImageFilterBaseIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetIsoSurfaceValue(self, _arg):
        r"""
        SetIsoSurfaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_SetIsoSurfaceValue(self, _arg)

    def GetIsoSurfaceValue(self):
        r"""GetIsoSurfaceValue(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_GetIsoSurfaceValue(self)

    def InsertNarrowBandNode(self, *args):
        r"""
        InsertNarrowBandNode(self, node)

        Parameters
        ----------
        node: itkBandNodeI3F const &

        InsertNarrowBandNode(self, index)

        Parameters
        ----------
        index: itkIndex3 const &

        InsertNarrowBandNode(self, index, value, nodestate)

        Parameters
        ----------
        index: itkIndex3 const &
        value: float const &
        nodestate: signed char const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_InsertNarrowBandNode(self, *args)

    def SetNarrowBandTotalRadius(self, val):
        r"""
        SetNarrowBandTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_SetNarrowBandTotalRadius(self, val)

    def GetNarrowBandTotalRadius(self):
        r"""GetNarrowBandTotalRadius(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_GetNarrowBandTotalRadius(self)

    def SetNarrowBandInnerRadius(self, val):
        r"""
        SetNarrowBandInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_SetNarrowBandInnerRadius(self, val)

    def GetNarrowBandInnerRadius(self):
        r"""GetNarrowBandInnerRadius(self) -> float"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_GetNarrowBandInnerRadius(self)

    def CreateNarrowBand(self):
        r"""CreateNarrowBand(self)"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_CreateNarrowBand(self)

    def SetNarrowBand(self, ptr):
        r"""
        SetNarrowBand(self, ptr)

        Parameters
        ----------
        ptr: itkNarrowBandBNI3F *

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_SetNarrowBand(self, ptr)

    def CopyInputToOutput(self):
        r"""CopyInputToOutput(self)"""
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_CopyInputToOutput(self)
    __swig_destroy__ = _itkNarrowBandImageFilterBasePython.delete_itkNarrowBandImageFilterBaseIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandImageFilterBaseIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_cast(obj)

# Register itkNarrowBandImageFilterBaseIF3IF3 in _itkNarrowBandImageFilterBasePython:
_itkNarrowBandImageFilterBasePython.itkNarrowBandImageFilterBaseIF3IF3_swigregister(itkNarrowBandImageFilterBaseIF3IF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def narrow_band_image_filter_base(*args: itkt.ImageLike,  iso_surface_value: float=..., narrow_band_total_radius: float=..., narrow_band_inner_radius: float=..., narrow_band=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for NarrowBandImageFilterBase"""
    import itk

    kwarg_typehints = { 'iso_surface_value':iso_surface_value,'narrow_band_total_radius':narrow_band_total_radius,'narrow_band_inner_radius':narrow_band_inner_radius,'narrow_band':narrow_band,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.NarrowBandImageFilterBase.New(*args, **kwargs)

    return instance.__internal_call__()

def narrow_band_image_filter_base_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKNarrowBand.NarrowBandImageFilterBase
    narrow_band_image_filter_base.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    narrow_band_image_filter_base.__doc__ = filter_object.__doc__



